/*
 *   File name: Version.h
 *   Summary:	Version number header for QDirStat
 *   License:	GPL V2 - See file LICENSE for details.
 *
 *   Author:	Stefan Hundhammer <Stefan.Hundhammer@gmx.de>
 */

#ifndef Version_h
#define Version_h

#define QDIRSTAT_VERSION "1.5"

#define RELEASE_VERSION  "1.5"
#define RELEASE_BASE_URL "https://github.com/shundhammer/qdirstat/releases/tag/"
#define RELEASE_URL      RELEASE_BASE_URL RELEASE_VERSION

#endif // Version_h
